==> me-1.0.0.tar.gz: lib/commands/feature_command.dart <==
import 'dart:io';

import 'package:bosun/bosun.dart';
import 'package:me/core/structure.dart';
import 'package:me/functions/create/create_file.dart';

import '../functions/binding/bindings.dart';
import '../functions/binding/controller.dart';
import '../functions/binding/find_file_by_type.dart';
import '../samples/impl/mega_provider.dart';
import '../utils/logger/log_utils.dart';

class FeatureCommand extends Command {
  FeatureCommand()
      : super(
          command: 'feature',
          description: 'Create a new feature for Megaleios projects. 🔨',
          example: 'feature login',
        );

  @override
  void run(List<String> args, Map<String, dynamic> flags) {
    if (args.isEmpty) {
      LogService.error("You must provide a feature name.");
      return;
    }
    makeNewFeature(featureName: args.first);
  }

  void makeNewFeature({required String featureName}) {
    _createProvider(featureName);
  }

  void _createProvider(String featureName) {
    final featurePath = 'lib/app/data';
    Directory(featurePath).createSync(recursive: true);
    _writeFiles(featurePath, featureName, overwrite: false);
  }

  void _writeFiles(
    String path,
    String featureName, {
    required bool overwrite,
  }) {
    final providerFile = createFile(
      name: featureName,
      command: 'provider',
      folderName: 'providers',
      sample: MegaProviderSample(
        '',
        featureName,
        overwrite: overwrite,
      ),
    );
    final providerPath = Structure.pathToDirImport(providerFile.path);
    var binindingPath = findFileFromNameAndType(
      'lib/app/modules/$featureName/bindings/',
      featureName,
      typeFile: TypeFile.binding,
    );
    if (binindingPath == null) {
      LogService.error('No binding found for $featureName');
      return;
    }

    if (binindingPath.isNotEmpty) {
      addDependencyToBinding(binindingPath, featureName);
    }

    final controllerPath = findFileFromNameAndType(
      'lib/app/modules/$featureName/controllers/',
      featureName,
      typeFile: TypeFile.controller,
    );

    if (controllerPath == null) {
      LogService.error('No controller found for $featureName');
      return;
    }

    if (controllerPath.isNotEmpty) {
      addConstructorToController(
        path: controllerPath,
        providerName: featureName,
      );
    }

    LogService.success("Created provider $providerPath");
  }
}

==> me-1.0.1.tar.gz: lib/commands/feature_command.dart <==
import 'dart:io';

import 'package:bosun/bosun.dart';
import 'package:me/core/structure.dart';
import 'package:me/functions/create/create_file.dart';

import '../functions/binding/bindings.dart';
import '../functions/binding/controller.dart';
import '../functions/binding/find_file_by_type.dart';
import '../samples/impl/mega_provider.dart';
import '../utils/logger/log_utils.dart';

class FeatureCommand extends Command {
  FeatureCommand()
      : super(
          command: 'feature',
          description: 'Create a new feature for Megaleios projects. 🔨',
          example: 'me feature login',
        );

  @override
  void run(List<String> args, Map<String, dynamic> flags) {
    if (args.isEmpty) {
      LogService.error("You must provide a feature name.");
      return;
    }
    makeNewFeature(featureName: args.first);
  }

  void makeNewFeature({required String featureName}) {
    _createProvider(featureName);
  }

  void _createProvider(String featureName) {
    final featurePath = 'lib/app/data';
    Directory(featurePath).createSync(recursive: true);
    _writeFiles(featurePath, featureName, overwrite: false);
  }

  void _writeFiles(
    String path,
    String featureName, {
    required bool overwrite,
  }) {
    final providerFile = createFile(
      name: featureName,
      command: 'provider',
      folderName: 'providers',
      sample: MegaProviderSample(
        '',
        featureName,
        overwrite: overwrite,
      ),
    );
    final providerPath = Structure.pathToDirImport(providerFile.path);
    var binindingPath = findFileFromNameAndType(
      'lib/app/modules/$featureName/bindings/',
      featureName,
      typeFile: TypeFile.binding,
    );
    if (binindingPath == null) {
      LogService.error('No binding found for $featureName');
      return;
    }

    if (binindingPath.isNotEmpty) {
      addDependencyToBinding(binindingPath, featureName);
    }

    final controllerPath = findFileFromNameAndType(
      'lib/app/modules/$featureName/controllers/',
      featureName,
      typeFile: TypeFile.controller,
    );

    if (controllerPath == null) {
      LogService.error('No controller found for $featureName');
      return;
    }

    if (controllerPath.isNotEmpty) {
      addConstructorToController(
        path: controllerPath,
        providerName: featureName,
      );
    }

    LogService.success("Created provider $providerPath");
  }
}
